@@ -1,9 +1,9 @@
 from typing import Optional
 
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 
 from dbt.adapters.base.relation import BaseRelation, Policy
-from dbt.exceptions import RuntimeException
+from dbt.exceptions import DbtRuntimeError
 
 
 @dataclass
@@ -22,19 +22,21 @@ class SparkIncludePolicy(Policy):
 
 @dataclass(frozen=True, eq=False, repr=False)
 class SparkRelation(BaseRelation):
-    quote_policy: SparkQuotePolicy = SparkQuotePolicy()
-    include_policy: SparkIncludePolicy = SparkIncludePolicy()
-    quote_character: str = '`'
+    quote_policy: Policy = field(default_factory=lambda: SparkQuotePolicy())
+    include_policy: Policy = field(default_factory=lambda: SparkIncludePolicy())
+    quote_character: str = "`"
     is_delta: Optional[bool] = None
+    is_hudi: Optional[bool] = None
+    information: Optional[str] = None
 
     def __post_init__(self):
         if self.database != self.schema and self.database:
-            raise RuntimeException('Cannot set database in spark!')
+            raise DbtRuntimeError("Cannot set database in spark!")
 
     def render(self):
         if self.include_policy.database and self.include_policy.schema:
-            raise RuntimeException(
-                'Got a spark relation with schema and database set to '
-                'include, but only one can be set'
+            raise DbtRuntimeError(
+                "Got a spark relation with schema and database set to "
+                "include, but only one can be set"
             )
         return super().render()
